@@ -1,17 +1,17 @@
-from .paginated_table import PaginatedTableRenderable
 from .build_history_table import BuildHistoryTableRenderable
-from .build_changes_table import BuildChangesTableRenderable
-from .info import InfoRenderable
 from .button import ButtonRenderable
-from .figlet_text import FigletTextRenderable
 from .executor_status_table import ExecutorStatusTableRenderable
+from .figlet_text import FigletTextRenderable
+from .help import HelpRenderable
+from .paginated_table import PaginatedTableRenderable
+from .text import TextRenderable
 
 __all__ = (
     "PaginatedTableRenderable",
     "BuildHistoryTableRenderable",
-    "BuildChangesTableRenderable",
-    "InfoRenderable",
     "ButtonRenderable",
     "FigletTextRenderable",
     "ExecutorStatusTableRenderable",
+    "TextRenderable",
+    "HelpRenderable",
 )
